from onegov.swissvotes.collections.pages import TranslatablePageCollection
from onegov.swissvotes.collections.votes import SwissVoteCollection


__all__ = (
    'SwissVoteCollection',
    'TranslatablePageCollection',
)
